@@ -1,6 +1,6 @@
-#!/bin/sh
+#!/bin/bash
 #
-# $Id: autogen.sh,v 1.2 2004/02/04 21:08:23 nilu Exp $
+# $Id: autogen.sh,v 1.6 2008/07/15 20:33:31 hartwork Exp $
 #
 # CppTest - A C++ Unit Testing Framework
 # Copyright (c) 2003 Niklas Lundell
@@ -24,18 +24,42 @@
 #
 # ---
 
-echo "Creating library tools..."
-libtoolize --automake --copy
+# --- Initialization of libtool
 
+echo "Creating library tools..."
+LIBTOOLIZE=libtoolize
+if glibtoolize --version &>/dev/null ; then
+	LIBTOOLIZE=glibtoolize
+fi
+${LIBTOOLIZE} --automake --copy --force --verbose
+
+# --- Creation of 'aclocal.m4'
+
+# The autotools are not backwards compatible with previous releases. 
+# Therefore, it often outputs non-important warnings that will be 
+# ignore and suppressed.
+#
 echo "Creating macros..."
-aclocal
+aclocal $aclocal_flags 2>&1 \
+	| grep -v 'warning: underquoted definition of' \
+	| grep -v 'Extending.aclocal' \
+	| grep -v 'Extending%20aclocal' 
+
+# --- Initialization of automake
+
+echo "Creating config/config.h.in..."
+autoheader
 
 echo "Creating Makefile templates..."
 touch README
 automake --gnu --add-missing --copy
 
+# --- Initialization of autoconf
+
 echo "Creating 'configure'..."
 autoconf
 
-echo -e "\nRun: ./configure; make; make install\n"
+# --- Finished...
+
+echo -e "\nRun: ./configure [OPTIONS]; make; make install\n"
 
